@@ -252,7 +252,10 @@ impl Connector for Bucket {
     ///     Ok(())
     /// }
     /// ```
+    #[instrument]
     async fn len(&mut self) -> Result<usize> {
+        info!("Start");
+
         let reg = Regex::new("[*]").unwrap();
         if reg.is_match(self.path.as_ref()) {
             return Err(Error::new(
@@ -270,7 +273,7 @@ impl Connector for Bucket {
         };
 
         //TODO: When rusoto will use last version of tokio we should remove the block_on.
-        Runtime::new()?.block_on(async {
+        let len = Runtime::new()?.block_on(async {
             match s3_client.head_object(request).await {
                 Ok(response) => match response.content_length {
                     Some(len) => Ok(len as usize),
@@ -287,7 +290,9 @@ impl Connector for Bucket {
                     }
                 }
             }
-        })
+        })?;
+
+        Ok(len)
     }
     /// See [`Connector::is_empty`] for more details.
     ///
@@ -342,7 +347,10 @@ impl Connector for Bucket {
     ///     Ok(())
     /// }
     /// ```
+    #[instrument]
     async fn fetch(&mut self) -> Result<()> {
+        info!("Start");
+
         let connector = self.clone();
         let s3_client = connector.s3_client();
         let request = GetObjectRequest {
@@ -413,9 +421,12 @@ impl Connector for Bucket {
     ///     Ok(())
     /// }
     /// ```
+    #[instrument]
     async fn send(&mut self, position: Option<isize>) -> Result<()> {
+        info!("Start");
+
         if self.is_variable() && *self.parameters == Value::Null && self.inner.get_ref().is_empty() {
-            warn!(slog_scope::logger(), "Can't flush with variable path and without parameters";"path"=>self.path.clone(),"parameters"=>self.parameters.to_string());
+            warn!(path = self.path.clone().as_str(), parameters = self.parameters.to_string().as_str(),  "Can't flush with variable path and without parameters");
             return Ok(());
         }
 
@@ -423,7 +434,7 @@ impl Connector for Bucket {
         let path_resolved = self.path();
 
         if !self.is_empty().await? {
-            info!(slog_scope::logger(), "Fetch previous data into S3"; "path" => path_resolved.to_string());
+            info!(path = path_resolved.to_string().as_str(),  "Fetch previous data into S3");
             {
                 let mut connector_clone = self.clone();
                 connector_clone.fetch().await?;
@@ -480,7 +491,10 @@ impl Connector for Bucket {
         self.metadata.clone()
     }
     /// See [`Connector::erase`] for more details.
+    #[instrument]
     async fn erase(&mut self) -> Result<()> {
+        info!("Start");
+
         let path_resolved = self.path();
         let s3_client = self.s3_client();
         let put_request = PutObjectRequest {
@@ -496,7 +510,9 @@ impl Connector for Bucket {
                 Ok(_) => Ok(()),
                 Err(e) => Err(Error::new(ErrorKind::NotFound, e)),
             }
-        })
+        })?;
+
+        Ok(())
     }
     /// See [`Connector::paginator`] for more details.
     async fn paginator(&self) -> Result<Pin<Box<dyn Paginator + Send>>> {
@@ -596,7 +612,7 @@ impl BucketPaginator {
                                 )
                             },
                             Err(e) => {
-                                warn!(slog_scope::logger(), "Can't fetch the list of keys"; "error" => e.to_string());
+                                warn!(error = e.to_string().as_str(),  "Can't fetch the list of keys");
                                 (Vec::default(), false, None)
                             }
                         }
@@ -706,7 +722,10 @@ impl Paginator for BucketPaginator {
     ///     Ok(())
     /// }
     /// ```
+    #[instrument]
     async fn next_page(&mut self) -> Result<Option<Box<dyn Connector>>> {
+        info!("Start");
+        
         let mut connector = self.connector.clone();
 
         Ok(match self.paths.next() {
